package com.example.julian.endlessroll.main.tutorial;

import android.util.Log;

import com.example.julian.endlessroll.main.GameLog;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/**
 * Created by Julian on 14.03.2017.
 */

public class Tutorial {

    private int levelId, levelPackId;
    private List<BreakPoint> breakPoints;

    private List<Integer> currentBreakPointIds = new ArrayList<>();
    private int lastBreakPointId = -1;
    private boolean overNewBreakPoints;

    public Tutorial(int levelId, int levelPackId, BreakPoint... breakPoints) {
        this.levelId = levelId;
        this.levelPackId = levelPackId;
        this.breakPoints = Arrays.asList(breakPoints);
    }

    public void reset(){
        currentBreakPointIds.clear();
        lastBreakPointId = -1;
        overNewBreakPoints = false;
    }

    public void update(float playerProgress) {
        playerProgress *= 2f;
        int nextBreakPoint = lastBreakPointId + 1;
        if (!currentBreakPointIds.isEmpty())
            currentBreakPointIds.clear();
        overNewBreakPoints = false;

        while (breakPoints.size() > nextBreakPoint && playerProgress >= breakPoints.get(nextBreakPoint).getX()) {
            currentBreakPointIds.add(nextBreakPoint);
            lastBreakPointId = nextBreakPoint;
            nextBreakPoint++;
            overNewBreakPoints = true;
        }
    }

    public boolean isOverNewBreakPoints() {
        return overNewBreakPoints;
    }

    public List<BreakPoint> getCurrentBreakPoints() {
        List<BreakPoint> list = new ArrayList<>();
        for (int i : currentBreakPointIds) {
            list.add(breakPoints.get(i));
        }
        return list;
    }

    public int getLevelId() {
        return levelId;
    }

    public int getLevelPackId() {
        return levelPackId;
    }
}
